@@ -454,7 +454,7 @@ describe('hx-trigger attribute', function() {
       div.dispatchEvent(event)
       this.server.respond()
       div.innerHTML.should.equal('Not Called')
-      foo = true
+      window.foo = true
       div.dispatchEvent(event)
       this.server.respond()
       div.innerHTML.should.equal('Called!')
@@ -496,6 +496,47 @@ describe('hx-trigger attribute', function() {
     }
   })
 
+  it('filters properly with true for empty condition', function() {
+    this.server.respondWith('GET', '/test', 'Called!')
+    var form = make('<form hx-get="/test" hx-trigger="evt[]">Not Called</form>')
+    form.click()
+    form.innerHTML.should.equal('Not Called')
+    var event = htmx._('makeEvent')('evt')
+    form.dispatchEvent(event)
+    this.server.respond()
+    form.innerHTML.should.equal('Called!')
+  })
+
+  it('syntax error in condition issues error', function() {
+    this.server.respondWith('GET', '/test', 'Called!')
+    var errorEvent = null
+    var handler = htmx.on('htmx:syntax:error', function(event) {
+      errorEvent = event
+    })
+    var form = make('<form hx-get="/test" hx-trigger="evt[{]">Not Called</form>')
+    try {
+      var event = htmx._('makeEvent')('evt')
+      form.dispatchEvent(event)
+      should.not.equal(null, errorEvent)
+      should.not.equal(null, errorEvent.detail.source)
+      console.log(errorEvent.detail.source)
+    } finally {
+      htmx.off('htmx:syntax:error', handler)
+    }
+  })
+
+  it('filters properly with condition containing square backets', function() {
+    this.server.respondWith('GET', '/test', 'Called!')
+    var form = make('<form hx-get="/test" hx-trigger="evt[foo[0]]">Not Called</form>')
+    form.click()
+    form.innerHTML.should.equal('Not Called')
+    var event = htmx._('makeEvent')('evt')
+    event.foo = [true]
+    form.dispatchEvent(event)
+    this.server.respond()
+    form.innerHTML.should.equal('Called!')
+  })
+
   it('from clause works', function() {
     var requests = 0
     this.server.respondWith('GET', '/test', function(xhr) {
@@ -982,6 +1023,60 @@ describe('hx-trigger attribute', function() {
     div2.innerHTML.should.equal('test 2')
   })
 
+  it('scrolling triggers revealed event', function(done) {
+    this.server.respondWith('GET', '/test', 'test')
+    this.server.autoRespond = true
+    this.server.autoRespondAfter = 0
+    var div = make('<div hx-get="/test" hx-trigger="revealed"></div>')
+    div.innerHTML.should.equal('')
+    div.scrollIntoView({ block: 'end', behavior: htmx.config.scrollBehavior })
+    htmx.trigger(document.body, 'scroll')
+
+    setTimeout(function() {
+      div.innerHTML.should.equal('test')
+      done()
+    }, 250)
+  })
+
+  if (window.__playwright__binding__) {
+    it('scrolling triggers intersect event', function(done) {
+      // test only works reliably with playwright
+      this.server.respondWith('GET', '/test', 'test')
+      this.server.autoRespond = true
+      this.server.autoRespondAfter = 0
+      var div = make('<div hx-get="/test" hx-trigger="intersect"></div>')
+      div.innerHTML.should.equal('')
+      div.scrollIntoView({ block: 'end', behavior: htmx.config.scrollBehavior })
+      htmx.trigger(document.body, 'scroll')
+
+      setTimeout(function() {
+        div.innerHTML.should.equal('test')
+        done()
+      }, 250)
+    })
+  }
+
+  it('triggering revealed while component not yet inited still works', function(done) {
+    this.server.respondWith('GET', '/test', 'test')
+    var div = make('<div hx-get="/test" hx-trigger="revealed"></div>')
+    var data = div['htmx-internal-data']
+    delete data.initHash // simulate not inited or revealed yet
+    div.removeAttribute('data-hx-revealed')
+    var server1 = this.server
+    div.innerHTML.should.equal('')
+    div.scrollIntoView({ block: 'end', behavior: htmx.config.scrollBehavior })
+    htmx.trigger(document.body, 'scroll')
+    setTimeout(function() {
+      server1.autoRespond = true
+      server1.autoRespondAfter = 0
+      htmx.process(div) // processing the div should also trigger revealed event now
+      setTimeout(function() {
+        div.innerHTML.should.equal('test')
+        done()
+      }, 10)
+    }, 250)
+  })
+
   it('reveal event works when triggered by window', function() {
     this.server.respondWith('GET', '/test1', 'test 1')
     var div = make('<div hx-get="/test1" hx-trigger="revealed" style="position: fixed; top: 1px; left: 1px; border: 3px solid red">foo</div>')
@@ -1130,10 +1225,6 @@ describe('hx-trigger attribute', function() {
   it('correctly handles CSS descendant combinators in modifier target', function() {
     this.server.respondWith('GET', '/test', 'Called')
 
-    document.addEventListener('htmx:syntax:error', function(evt) {
-      chai.assert.fail('htmx:syntax:error')
-    })
-
     make('<div class="d1"><a id="a1" class="a1">Click me</a><a id="a2" class="a2">Click me</a></div>')
     var div = make('<div hx-trigger="click from:body target:(.d1 .a2)" hx-get="/test">Not Called</div>')
 
@@ -1148,12 +1239,52 @@ describe('hx-trigger attribute', function() {
 
   it('correctly handles CSS descendant combinators in modifier root', function() {
     this.server.respondWith('GET', '/test', 'Called')
-
-    document.addEventListener('htmx:syntax:error', function(evt) {
-      chai.assert.fail('htmx:syntax:error')
+    var errorEvent = null
+    var handler = htmx.on('htmx:syntax:error', function(event) {
+      errorEvent = event
     })
+    var form = make('<div hx-trigger="intersect root:{form input}" hx-get="/test">Not Called</div>')
+    try {
+      var event = htmx._('makeEvent')('evt')
+      form.dispatchEvent(event)
+      should.equal(null, errorEvent)
+    } finally {
+      htmx.off('htmx:syntax:error', handler)
+    }
+  })
 
-    make('<div hx-trigger="intersect root:{form input}" hx-get="/test">Not Called</div>')
+  it('correctly handles intersect with modifier threshold', function() {
+    this.server.respondWith('GET', '/test', 'Called')
+    var errorEvent = null
+    var handler = htmx.on('htmx:syntax:error', function(event) {
+      errorEvent = event
+    })
+    var form = make('<div hx-trigger="intersect threshold:0.5" hx-get="/test">Not Called</div>')
+    try {
+      var event = htmx._('makeEvent')('evt')
+      form.dispatchEvent(event)
+      should.equal(null, errorEvent)
+    } finally {
+      htmx.off('htmx:syntax:error', handler)
+    }
+  })
+
+  it('issues error with invalid trigger spec', function() {
+    this.server.respondWith('GET', '/test', 'Called')
+    var errorEvent = null
+    var handler = htmx.on('htmx:syntax:error', function(event) {
+      errorEvent = event
+    })
+    var form = make('<div hx-trigger="intersect invalid:0.5" hx-get="/test">Not Called</div>')
+    try {
+      var event = htmx._('makeEvent')('evt')
+      form.dispatchEvent(event)
+      should.not.equal(null, errorEvent)
+      should.not.equal(null, errorEvent.detail.source)
+      console.log(errorEvent.detail.source)
+    } finally {
+      htmx.off('htmx:syntax:error', handler)
+    }
   })
 
   it('uses trigger specs cache if defined', function() {
@@ -1223,4 +1354,20 @@ describe('hx-trigger attribute', function() {
     this.server.respond()
     div.innerHTML.should.equal('Requests: 2')
   })
+
+  it('Removing polling trigger and processing node removes timeout', function(complete) {
+    this.server.respondWith('GET', '/test', 'Called!')
+    var div = make('<div hx-get="/test" hx-trigger="every 5ms">Not Called</div>')
+    div.removeAttribute('hx-trigger')
+    should.not.equal(div['htmx-internal-data'].timeout, undefined)
+    htmx.process(div)
+    should.equal(div['htmx-internal-data'].timeout, undefined)
+    this.server.autoRespond = true
+    this.server.autoRespondAfter = 0
+    setTimeout(function() {
+      div.innerHTML.should.equal('Not Called')
+      delete window.foo
+      complete()
+    }, 30)
+  })
 })
